All Classes and Interfaces

Class
Description
You do not have sufficient access to perform this action.
 
 
An AWS Arn.
 
 
 
 
 
A type of SourceCodeType that specifies a code diff between a source and destination branch in an associated repository.
 
Code artifacts are source code artifacts and build artifacts used in a repository analysis or a pull request review.
 
Information about an Amazon Web Services CodeCommit repository.
 
Service client for accessing CodeGuruReviewer asynchronously.
A builder for creating an instance of CodeGuruReviewerAsyncClient.
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the resource will never enter into the desired state.
 
 
The parameters object used to resolve the auth schemes for the CodeGuruReviewer service.
An auth scheme provider for CodeGuruReviewer service.
This includes configuration specific to CodeGuruReviewer that is supported by both CodeGuruReviewerClientBuilder and CodeGuruReviewerAsyncClientBuilder.
Service client for accessing CodeGuruReviewer.
A builder for creating an instance of CodeGuruReviewerClient.
 
The parameters object used to resolve an endpoint for the CodeGuruReviewer service.
 
An endpoint provider for CodeGuruReviewer.
 
 
 
 
 
 
 
 
 
 
 
 
Class to expose the service client settings to the user.
 
Waiter utility class that polls a resource until a desired state is reached or until it is determined that the resource will never enter into the desired state.
 
Information about a code review.
 
Information about the summary of the code review.
 
The type of a code review.
 
A type of SourceCodeType that specifies the commit diff for a pull request on an associated repository.
 
 
The requested operation would cause a conflict with the current state of a service resource associated with the request.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Link between an endpoint property and the AwsEndpointAttribute it represents.
 
 
Information about an event.
 
Identifiers for variables declared within the rule engine, e.g.
The server encountered an internal error and is unable to complete the request.
 
 
An intermediate value for JMESPath expressions, encapsulating the different data types supported by JMESPath and the operations on that data.
 
An object that contains:
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Information about the statistics from the code review.
 
Information about metrics summaries.
 
The resource specified in the request was not found.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Information about the recommendation feedback.
 
Information about recommendation feedback summaries.
 
Information about recommendations.
 
 
 
Information about an associated Amazon Web Services CodeCommit repository or an associated repository that is managed by Amazon Web Services CodeStar Connections (for example, Bitbucket).
 
A code review type that analyzes all code under a specified branch in an associated repository.
 
Information about a repository association.
 
 
Summary information about a repository association.
 
A SourceCodeType that specifies the tip of a branch in an associated repository.
 
Metadata that is associated with a code review.
 
The resource specified in the request was not found.
 
 
Metadata about a rule.
 
 
 
 
 
Represents a URL to be used internally for endpoint resolution.
Information about an associated repository in an S3 bucket.
 
Information about a repository in an S3 bucket.
 
Specifies the name of an S3 bucket and a CodeArtifacts object that contains the S3 object keys for a source code .zip file and for a build artifacts .zip file that contains .jar or .class files.
 
 
 
Specifies the source code that is analyzed in a code review.
 
 
 
 
 
Information about a third-party source repository connected to CodeGuru Reviewer.
 
The request was denied due to request throttling.
 
 
 
 
 
 
 
The input fails to satisfy the specified constraints.
 
Base class for the types of values computable by the RuleEngine.
An array value.
A boolean value.
 
 
An integer value.
 
A record (map) value.
A string value.
 
Contains classes used at runtime by the code generator classes for waiter acceptors generated from JMESPath expressions.
A WaiterAcceptor implementation that checks for a specific HTTP response status, regardless of whether it's reported by a response or an exception.